<?php

/**
 * @file
 * Rules integration by Bot Rules (botrules) module.
 */

/**
 * Implements hook_rules_action_info().
 */
function botrules_rules_action_info() {
  $actions = array(
    'botrules_action_message' => array(
      'label' => t('Send a message to IRC channel or user'),
      'group' => t('Bot'),
      'parameter' => array(
        'target' => array(
          'type' => 'text',
          'label' => t('Channel/nickname'),
        ),
        'text' => array(
          'type' => 'text',
          'label' => t('Message text'),
        ),
      ),
    ),
    'botrules_action_action' => array(
      'label' => t('Send an action to IRC channel or user'),
      'group' => t('Bot'),
      'parameter' => array(
        'target' => array(
          'type' => 'text',
          'label' => t('Channel/nickname'),
          'description' => t('Keep in mind that not all IRC clients are capable of sensibly displaying action to a user'),
        ),
        'text' => array(
          'type' => 'text',
          'label' => t('Action text'),
        ),
      ),
    ),
  );
  if (module_exists('bot_agotchi')) {
    $actions['botrules_action_modify_botagotchi_greetings'] = array(
      'label' => t('Modify Botagotchi greeting responses'),
      'group' => t('Bot'),
      'parameter' => array(
        'responses' => array(
          'type' => 'text',
          'label' => t('Greeting responses (one per line)'),
        ),
      ),
    );
    $actions['botrules_action_modify_botagotchi_feeding'] = array(
      'label' => t('Modify Botagotchi feeding responses'),
      'group' => t('Bot'),
      'parameter' => array(
        'responses' => array(
          'type' => 'text',
          'label' => t('Feeding responses (one per line)'),
        ),
      ),
    );
  }
  return $actions;
}

/**
 * Implements hook_rules_condition_info().
 */
function botrules_rules_condition_info() {
  $conditions = array(
    'botrules_condition_bot_on_channel' => array(
      'label' => t('Bot is on a channel'),
      'group' => t('Bot'),
      'parameter' => array(
        'channel' => array(
          'type' => 'text',
          'label' => t('Channel'),
        ),
      ),
    ),
    'botrules_condition_nick_on_channel' => array(
      'label' => t('Nickname is on a channel'),
      'group' => t('Bot'),
      'parameter' => array(
        'nickname' => array(
          'type' => 'text',
          'label' => t('Nickname'),
        ),
        'channel' => array(
          'type' => 'text',
          'label' => t('Channel'),
        ),
      ),
      'description' => t('Returns TRUE only if the bot is on the channel, too.'),
    ),
    'botrules_condition_nick_on_any_channel' => array(
      'label' => t("Nickname is on any of bot's channels"),
      'group' => t('Bot'),
      'parameter' => array(
        'nickname' => array(
          'type' => 'text',
          'label' => t('Nickname'),
        ),
      ),
    ),
  );
  return $conditions;
}

/**
 * Implements hook_rules_event_info().
 */
function botrules_rules_event_info() {
  $events = array(
    'botrules_event_got_channel_message' => array(
      'label' => t('Received a channel message'),
      'group' => t('Bot'),
      'variables' => array(
        'channel' => array(
          'type' => 'text',
          'label' => t('Channel'),
        ),
        'nickname' => array(
          'type' => 'text',
          'label' => t('Nickname'),
        ),
        'message' => array(
          'type' => 'text',
          'label' => t('Message'),
        ),
      ),
    ),
    'botrules_event_got_private_message' => array(
      'label' => t('Received a private message'),
      'group' => t('Bot'),
      'variables' => array(
        'nickname' => array(
          'type' => 'text',
          'label' => t('Nickname'),
        ),
        'message' => array(
          'type' => 'text',
          'label' => t('Message'),
        ),
      ),
    ),
  );
  return $events;
}

/**
 * The action function for 'botrules_action_message'.
 *
 * @param string $target
 *   Target of the action (nickname or channel).
 * @param string $text
 *   Body of the message.
 */
function botrules_action_message($target, $text) {
  global $irc;
  bot_message($target, $text);
}

/**
 * The action function for 'botrules_action_action'.
 *
 * @param string $target
 *   Target of the action (nickname or channel).
 * @param string $text
 *   Text of the action.
 */
function botrules_action_action($target, $text) {
  global $irc;
  bot_action($target, $text);
}

/**
 * The action function for 'botrules_action_modify_botagotchi_greetings'.
 *
 * @param string $responses
 *   Response strings (newline-delimited).
 */
function botrules_action_modify_botagotchi_greetings($responses) {
  variable_set('bot_agotchi_greeting_responses', $responses);
}

/**
 * The action function for 'botrules_action_modify_botagotchi_feeding'.
 *
 * @param string $responses
 *   Response strings (newline-delimited).
 */
function botrules_action_modify_botagotchi_feeding($responses) {
  variable_set('bot_agotchi_feeding_responses', $responses);
}

/**
 * The condition function for 'botrules_condition_bot_on_channel'.
 *
 * @param string $channel
 *   Channel name.
 */
function botrules_condition_bot_on_channel($channel) {
  global $irc;
  if (isset($irc->_channels[$channel])) {
    return TRUE;
  }
  return FALSE;
}

/**
 * The condition function for 'botrules_condition_nick_on_channel'.
 *
 * @param string $nick
 *   Nickname.
 * @param string $channel
 *   Channel name.
 */
function botrules_condition_nick_on_channel($nick, $channel) {
  global $irc;
  $nick = drupal_strtolower($nick);
  if (isset($irc->_channels[$channel]->users[$nick])) {
    return TRUE;
  }
  return FALSE;
}

/**
 * The condition function for 'botrules_condition_nick_on_any_channel'.
 *
 * @param string $nick
 *   Nickname.
 */
function botrules_condition_nick_on_any_channel($nick) {
  global $irc;
  $nick = drupal_strtolower($nick);
  $nicks = array();
  foreach ($irc->_channels as $channel) {
    $nicks = array_merge($nicks, array_keys($channel->users));
  }
  if (in_array($nick, $nicks)) {
    return TRUE;
  }
  return FALSE;
}
